/******************************************************************************
//
// check-sdl-version
// Copyright (c) 2010 Eris Caffee
// Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
//
//
// Just a quick test program to verify SDL installation and to use as an
// example for learning to use CMake.
// 
******************************************************************************/

#include <stdio.h>
#include <SDL.h>


/* Redirect I/O on Windows to a file.  We would not need to do this in a 
   console app. */
#ifdef WIN32
#include <windows.h>
#include <io.h>
void redirect_stdio(void)
   {
   /* We must freopen stderr to get it to have a valid fd before we can 
      dup it to stdout.  This creates a file on disk, which we then delete. */
   freopen("stdout.txt", "w", stdout);
   freopen("stderr.txt", "w", stderr);
   if (_dup2(_fileno(stdout), _fileno(stderr)) != 0)
      fprintf(stdout, "_dup2 failed!\n");
   DeleteFile("stderr.txt");
   }
#endif

int main(int argc, char **argv)
   {
   SDL_version compiled;
   const SDL_version * linked;

#ifdef WIN32
   redirect_stdio();
#endif

   printf("\t\t\tCompiled\t\tLinked\n");

   SDL_VERSION(&compiled);
   linked = SDL_Linked_Version();
   printf("SDL version\t\t%d.%d.%d\t\t\t%d.%d.%d\n", 
	  compiled.major, compiled.minor, compiled.patch,
	  linked->major, linked->minor, linked->patch);

   return 0;
   }
